@@ -30,6 +30,9 @@ describe 'designate::central' do
         is_expected.to contain_designate_config('service:central/backend_driver').with_value('bind9')
         is_expected.to contain_designate_config('service:central/managed_resource_email').with_value('hostmaster@example.com')
         is_expected.to contain_designate_config('service:central/managed_resource_tenant_id').with_value('123456')
+        is_expected.to contain_designate_config('service:central/max_domain_name_len').with_value('255')
+        is_expected.to contain_designate_config('service:central/max_recordset_name_len').with_value('255')
+        is_expected.to contain_designate_config('service:central/min_ttl').with_value('None')
       end
 
       context 'when using Power DNS backend driver' do
@@ -39,53 +42,46 @@ describe 'designate::central' do
         end
       end
     end
+
+    context 'with custom package name' do
+      before do
+        params.merge!({ :central_package_name => 'designate-central-custom-name' })
+      end
+
+      it 'configures using custom name' do
+        is_expected.to contain_package('designate-central').with(
+          :name      => 'designate-central-custom-name',
+          :ensure    => 'present',
+          :tag       => ['openstack', 'designate-package'],
+        )
+      end
+    end
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      { :osfamily => 'Debian' }
-    end
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
 
-    let :platform_params do
-      {
-        :central_package_name => 'designate-central',
-        :central_service_name => 'designate-central'
-      }
+      let(:platform_params) do
+        case facts[:osfamily]
+        when 'Debian'
+          {
+            :central_package_name => 'designate-central',
+            :central_service_name => 'designate-central'
+          }
+        when 'RedHat'
+          {
+            :central_package_name => 'openstack-designate-central',
+            :central_service_name => 'openstack-designate-central'
+          }
+        end
+      end
+      it_behaves_like 'designate-central'
     end
-
-    it_configures 'designate-central'
   end
 
-  context 'on RedHat platforms' do
-    let :facts do
-      { :osfamily => 'RedHat' }
-    end
-
-    let :platform_params do
-      {
-        :central_package_name => 'openstack-designate-central',
-        :central_service_name => 'openstack-designate-central'
-      }
-    end
-
-    it_configures 'designate-central'
-  end
-
-  context 'with custom package name' do
-    let :facts do
-      { :osfamily => 'RedHat' }
-    end
-
-    let :platform_params do
-      { :central_package_name => 'designate-central-custom-name',
-        :central_service_name => 'openstack-designate-central'
-      }
-    end
-
-    before do
-      params.merge!({ :central_package_name => 'designate-central-custom-name' })
-    end
-
-    it_configures 'designate-central'
-  end
 end
